#!/usr/bin/env bash
###
 # Installs and sets up database for given system.
 ##


# Import utils script.
. ./src/$(dirname ${0})/utils.sh


# Stop on error.
set -e


###
 # Script entry point.
 ##
function main () {
    echo ""
    echo "Please enter OS type:"
    echo -e "    ${text_cyan}1${text_reset}) Arch Linux"
    echo -e "    ${text_cyan}2${text_reset}) Ubuntu"
    echo -e "    ${text_cyan}3${text_reset}) Other"
    echo ""
    read user_input

    # Handle user input.
    if [[ ${user_input} == 1 ]]
    then
        # Handle for Arch Linux.
        echo "Choose a DB type to install:"
        echo -e "    ${text_cyan}1${text_reset}) MariaDB"
        echo -e "    ${text_cyan}2${text_reset}) PostgreSQL"
        echo ""
        read user_input

        # Handle user input.
        if [[ ${user_input} == 1 ]]
        then
            # Handle for MariaDB install.
            echo -e "${text_blue}Installing MariaDB for Arch Linux.${text_reset}"
            echo -e "${text_blue}Sudo is required for installing/updating system files.${text_reset}"
            echo -e "${text_blue}This may ask for your system password.${text_reset}"
            echo -e "${text_blue}To continue, press ${text_cyan}enter${text_blue}. Otherwise, hit ${text_cyan}ctrl+c${text_blue} to cancel.${text_reset}"
            read

            echo -e "${text_blue}Starting MariaDB installation.${text_reset}"
            sudo ./install_mysql.sh --os arch --db mariadb
            echo -e "${text_green}MariaDB setup & installation complete.${text_reset}"

        elif [[ ${user_input} == 2 ]]
        then
            echo -e "${text_blue}Installing PostgreSQL for Arch Linux.${text_reset}"
            echo -e "${text_blue}Sudo is required for installing/updating system files.${text_reset}"
            echo -e "${text_blue}This may ask for your system password.${text_reset}"
            echo -e "${text_blue}To continue, press ${text_cyan}enter${text_blue}. Otherwise, hit ${text_cyan}ctrl+c${text_blue} to cancel.${text_reset}"
            read

            echo -e "${text_blue}Starting PostgreSQL installation.${text_reset}"
            sudo ./install_postgresql.sh --os arch
            echo -e "${text_green}PostgreSQL setup & installation complete.${text_reset}"
        fi

    elif [[ ${user_input} == 2 ]]
    then
        # Handle for Ubuntu.
        echo "Choose a DB type to install:"
        echo -e "    ${text_cyan}1${text_reset}) MySQL"
        echo -e "    ${text_cyan}2${text_reset}) MariaDB"
        echo -e "    ${text_cyan}3${text_reset}) PostgreSQL"
        echo ""
        read user_input

        # Handle user input.
        if [[ ${user_input} == 1 ]]
        then
            # Handle for MySQL install.
            echo -e "${text_blue}Installing MySQL for Ubuntu Linux.${text_reset}"
            echo -e "${text_blue}Sudo is required for installing/updating system files.${text_reset}"
            echo -e "${text_blue}This may ask for your system password.${text_reset}"
            echo -e "${text_blue}To continue, press ${text_cyan}enter${text_blue}. Otherwise, hit ${text_cyan}ctrl+c${text_blue} to cancel.${text_reset}"
            read

            echo -e "${text_blue}Starting MySQL installation.${text_reset}"
            sudo ./install_mysql.sh --os ubuntu --db mysql
            echo -e "${text_green}MySQL setup & installation complete.${text_reset}"

        elif [[ ${user_input} == 2 ]]
        then
            # Handle for MariaDB install.
            echo -e "${text_blue}Installing MariaDB for Ubuntu Linux.${text_reset}"
            echo -e "${text_blue}Sudo is required for installing/updating system files.${text_reset}"
            echo -e "${text_blue}This may ask for your system password.${text_reset}"
            echo -e "${text_blue}To continue, press ${text_cyan}enter${text_blue}. Otherwise, hit ${text_cyan}ctrl+c${text_blue} to cancel.${text_reset}"
            read

            echo -e "${text_blue}Starting MariaDB installation.${text_reset}"
            sudo ./install_mysql.sh --os ubuntu --db mariadb
            echo -e "${text_green}MariaDB setup & installation complete.${text_reset}"

        elif [[ ${user_input} == 3 ]]
        then
            # Handle for PostgreSQL install.
            echo -e "${text_blue}Installing PostgreSQL for Ubuntu Linux.${text_reset}"
            echo -e "${text_blue}Sudo is required for installing/updating system files.${text_reset}"
            echo -e "${text_blue}This may ask for your system password.${text_reset}"
            echo -e "${text_blue}To continue, press ${text_cyan}enter${text_blue}. Otherwise, hit ${text_cyan}ctrl+c${text_blue} to cancel.${text_reset}"
            read

            echo -e "${text_blue}Starting PostgreSQL installation.${text_reset}"
            sudo ./install_postgresql.sh --os ubuntu
            echo -e "${text_green}PostgreSQL setup & installation complete.${text_reset}"

        else
            # Unhandled type.
            echo -e "${text_orange}Unknown option entered.${text_reset}"
        fi

    else
        # Handle for all other OS types.
        echo -e "${text_orange}Other OS types are currently unsupported.${text_reset}"
    fi
}


main
