#!/usr/bin/env bash
###
 # Install and set up for MySQL/MariaDB.
 ##


# Import utils script.
. $(dirname ${0})/utils.sh


# Stop on error.
set -e


###
 # Script entry point.
 # Checks that expected args were provided, to indicate what database type is being installed to what OS.
 # Then calls the corresponding function to actually execute logic.
 ##
function main () {

    check_is_user root

    # Check that expected os key exists.
    if [[ ! ${!kwargs[@]} =~ "os" ]]
    then
        echo -e "${text_red}Failed to provide expected OS kwarg. Terminating script.${text_reset}"
        exit 1
    fi

    # Check os to install for.
    if [[ ${kwargs["os"]} == "arch" ]]
    then
        # Handle for Arch Linux.
        install_arch_postgres

    elif [[ ${kwargs["os"]} == "ubuntu" ]]
    then
        # Handle for Ubuntu.
        install_ubuntu_postgres

    else
        echo -e "${text_red}Unrecognized OS type. Terminating script.${text_reset}"
        exit 1
    fi

}


###
 # Installation logic for Arch Linux systems.
 ##
function install_arch_postgres () {

    # Install PostgreSQL.
    sudo pacman -Syu postgresql --noconfirm > /dev/null

    # Run initial configuration.
    sudo -u postgres initdb --locale=en_US.UTF-8 -E UTF8 -D /var/lib/postgres/data

    # Start PostgreSQL service and set to start on boot.
    sudo systemctl start postgresql.service > /dev/null
    sudo systemctl enable postgresql.service > /dev/null

}


###
 # Installation logic for Ubuntu Linux systems.
 ##
function install_ubuntu_postgres () {

    # Install PostgreSQL.
    sudo apt-get update > /dev/null 2>&1
    sudo apt install postgresql postgresql-contrib -y

}


main
